==> apache-tinkerpop-3.4.10-src.zip: tinkerpop-3.4.10/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/lambda/ConstantTraversal.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.process.traversal.lambda;

import java.util.Objects;

/**
 * @author Marko A. Rodriguez (http://markorodriguez.com)
 */
public final class ConstantTraversal<S, E> extends AbstractLambdaTraversal<S, E> {

    private final E end;

    public ConstantTraversal(final E end) {
        this.end = end;
    }

    @Override
    public E next() {
        return this.end;
    }

    @Override
    public String toString() {
        return "(" + this.end.toString() + ")";
    }

    @Override
    public int hashCode() {
        return this.getClass().hashCode() ^ this.end.hashCode();
    }

    @Override
    public boolean equals(final Object other) {
        return other instanceof ConstantTraversal
                && Objects.equals(((ConstantTraversal) other).end, this.end);
    }
}

==> apache-tinkerpop-3.8.0-src.zip: tinkerpop-3.8.0/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/lambda/ConstantTraversal.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.process.traversal.lambda;

import org.apache.tinkerpop.gremlin.process.traversal.Traversal;

import java.util.Objects;

/**
 * A {@link Traversal} that always returns a constant value.
 *
 * @author Marko A. Rodriguez (http://markorodriguez.com)
 */
public final class ConstantTraversal<S, E> extends AbstractLambdaTraversal<S, E> {

    private final E end;

    public ConstantTraversal(final E end) {
        this.end = end;
    }

    @Override
    public E next() {
        return this.end;
    }

    @Override
    public String toString() {
        return "(" + Objects.toString(this.end) + ")";
    }

    @Override
    public int hashCode() {
        return this.getClass().hashCode() ^ Objects.hashCode(this.end);
    }

    @Override
    public boolean equals(final Object other) {
        return other instanceof ConstantTraversal
                && Objects.equals(((ConstantTraversal) other).end, this.end);
    }
}
